Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2009)

Unified Diff: webrtc/api/objc/RTCRtpCodecParameters+Private.h

Issue 1885473004: Adding codecs to the RtpParameters returned by an RtpSender. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Responding to review comments. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/api/objc/RTCRtpCodecParameters+Private.h
diff --git a/webrtc/api/objc/RTCRtpParameters+Private.h b/webrtc/api/objc/RTCRtpCodecParameters+Private.h
similarity index 61%
copy from webrtc/api/objc/RTCRtpParameters+Private.h
copy to webrtc/api/objc/RTCRtpCodecParameters+Private.h
index e0370338f3b70a6057ed26d85879193368eada65..aabbf7d0a1bb73abf53ea77a0b18518d942969f3 100644
--- a/webrtc/api/objc/RTCRtpParameters+Private.h
+++ b/webrtc/api/objc/RTCRtpCodecParameters+Private.h
@@ -10,20 +10,20 @@
#import <Foundation/Foundation.h>
-#import "webrtc/api/objc/RTCRtpParameters.h"
+#import "webrtc/api/objc/RTCRtpCodecParameters.h"
#include "webrtc/api/rtpparameters.h"
NS_ASSUME_NONNULL_BEGIN
-@interface RTCRtpParameters ()
+@interface RTCRtpCodecParameters ()
-/** Returns the equivalent native RtpParameters structure. */
-@property(nonatomic, readonly) webrtc::RtpParameters nativeParameters;
+/** Returns the equivalent native RtpCodecParameters structure. */
+@property(nonatomic, readonly) webrtc::RtpCodecParameters nativeParameters;
-/** Initialize the object with a native RtpParameters structure. */
+/** Initialize the object with a native RtpCodecParameters structure. */
- (instancetype)initWithNativeParameters:
- (const webrtc::RtpParameters &)nativeParameters;
+ (const webrtc::RtpCodecParameters &)nativeParameters;
@end

Powered by Google App Engine
This is Rietveld 408576698